@@ -39,9 +39,14 @@ INSTRUMENT_LIBS = {
     "urllib": True,
     "suds": True,
     "subprocess": True,
+    "paramiko": True,
 }
 
 
+def load(_):
+    pass
+
+
 def instrument_all(**instrument_libs):
     libs = INSTRUMENT_LIBS.copy()
     libs.update(instrument_libs)
